/*
 * @Description: 打印模板方法数据相关
 * @Author: Ben Lin
 * @version: 
 * @Date: 2024-06-13 16:18:39
 * @LastEditors: your name
 * @LastEditTime: 2024-06-17 11:27:09
 */
import { h, unref } from "vue";
import { ActionItem, BasicColumn, FormSchema } from "/@/components/Table";
import { Tag, Tooltip } from "ant-design-vue";
import { GetEnum } from "/@/api/tigerapi/system";
import { useLocale } from "/@/locales/useLocale";
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();
const { getLocale } = useLocale();
export const firstColumns: BasicColumn[] = [
    {
        dataIndex: "LABEL_ID",
        title: "标签模板ID",
        ifShow: false,
        sorter: true,
        resizable: true,
    },
    {
        dataIndex: "VAR_NAME",
        title: "变量名称",
        ifShow: true,
        sorter: true,
        resizable: true,
        customRender: () => { }
    },
    {
        dataIndex: "VAR_TYPE",
        title: "变量类型",
        ifShow: true,
        sorter: true,
        resizable: true,
        customRender: ({ record }) => {
            let color = ''; let text = '';
            switch (record.VAR_TYPE) {
                case 0:
                    text = '常量';
                    color = 'green';
                    break;
                case 1:
                    text = '过程变量';
                    color = 'orange';
                    break;
                case 2:
                    text = '日期变量';
                    color = '#4f68b0';
                    break;
                case 3:
                    text = '自定义变量';
                    color = '#bfbfbf';
                    break;
            }
            return h(Tooltip, { title: text }, () => h(Tag, { color: color }, () => text),);
        }
    },
    {
        dataIndex: "VAR_VALUE",
        title: "变量值",
        ifShow: true,
        sorter: true,
        resizable: true,
    },
    {
        dataIndex: "REMARK",
        title: "备注",
        ifShow: true,
        sorter: true,
        resizable: true,
    }];

export const secondColumns: BasicColumn[] = [];

let isShow = false;
export const firstFormSchemas: FormSchema[] = [
    {
        field: 'ID',
        label: '变量ID',
        component: 'Input',
        colProps: {
            span: 20,
        },
        show: false,
    },
    {
        field: 'LABEL_ID',
        label: '标签模板ID',
        component: 'Input',
        colProps: {
            span: 20,
        },
        show: false,
    },
    {
        field: 'VAR_NAME',
        label: '变量名',
        required: true,
        component: 'Input',
        colProps: {
            span: 20,
        },
    },
    {
        field: 'VAR_TYPE',
        label: '变量类型',
        component: 'ApiSelect',
        colProps: {
            span: 20,
        },
        componentProps: {
            api: GetEnum,
            params: { name: 'BAS_LABEL_VAR+VAR_TYPEs' },
            resultField: 'Data',
            labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
            valueField: 'Value',
            onChange: (e) => {
                if(e == 1){
                    isShow = true;
                }else{
                    isShow = false;
                }
            }
        },
    },
    {
        field: 'VAR_VALUE',
        label: '变量值',
        required: true,
        component: 'Input',
        colProps: {
            span: 20,
        },
    },
    {
        field:"BAS_LABEL_PV1PSelect_0", //按低代码配置的规则，实体名+序号+PSelect_0，序号用来区分多个的时候，PSelect_0这是个固定后缀
        label:"1",
        defaultValue:"BAS_LABEL_PV",
        component:"Input",
        colProps:{"span":4},
        ifShow: ({ values }) => isShow,
        colSlot:"BAS_LABEL_PV1add" //按低代码配置的规则，实体名+序号+add，序号用来区分多个的时候，add这是个固定后缀
    },
    {
        field: 'REMARK',
        label: '备注',
        component: 'Input',
        colProps: {
            span: 20,
        },
    },
];
export const secondFormSchemas: FormSchema[] = [];

export const firstSearchForm: FormSchema[] = [
    {
        field: 'VAR_NAME',
        label: t('变量名'),
        colProps: { span: 8 },
        component: 'Input',
    },
];

export const labelActionItem: ActionItem[] = [
    {
        icon: 'clarity:info-standard-line',
        tooltip: '模板变量',
        onClick: () => { },
    },
];

/**
 * @description: 跳转到详情页面方法
 * @param {Fn} go
 * @return {*}
 */
export function goDetail(go: Fn, record: Recordable) {
    const id = {
        ID: 'BAS_LABEL_VAR',
        firstTabName: '标签模板变量',
        secondTabName:'', //'标签过程变量',
        firstTitle: '模板变量',
        secondTitle: '', //'过程变量',
        pageTitle: '标签模板变量', //详情页面标题
        contentStr: '这里是标签模板变量管理页面，可以管理标签的模板变量或者打印过程中的变量',
        detailName: `模板[${record.LABEL_NAME}]`,
        others: { LABEL_ID: record.ID },
        colSlots: ['BAS_LABEL_PV1add'],
    };
    go(`/BAS_LABEL_VAR/${encodeURI(JSON.stringify(id))}`);
}

export function labelOpenSelectItem(openItemModal: Fn) {
    openItemModal(true, {
      title: '过程变量列表',
      schemas: [
        {
          field: 'VAR_CODE',
          component: 'Input',
          label: '过程变量编码',
          colProps: {
            span: 12,
          },
        },
      ],
      ItemColumns: [
        {
          title: t('过程变量编码'),
          dataIndex: 'VAR_CODE',
          resizable: true,
          sorter: true,
          width: 200,
        },
        {
          title: t('过程变量名称'),
          dataIndex: 'VAR_NAME',
          resizable: true,
          sorter: true,
          width: 180,
        },
      ],
      tableName: 'BAS_LABEL_PV',
      rowKey: 'VAR_CODE',
      searchInfo: {TABLE_NAME: 'BAS_LABEL_PV'}
    });
  }

  /**
   * @description: 选择过程变量弹出选择框成功返回赋值方法
   * @param {*} d
   * @param {*} u
   * @return {*}
   */  
  export function labelGetSelectSuccess(d, u) {
    return {
        VAR_VALUE: d.values['val'],
    };
  }